==> dde-calendar_5.9.5.orig.tar.xz: dde-calendar-5.9.5/translations/dde-calendar-service_sq.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="sq">
<context>
    <name>DAccountDataBase</name>
    <message>
        <source>Work</source>
        <translation>Pune</translation>
    </message>
    <message>
        <source>Life</source>
        <translation>Shtëpie</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>Tjetër</translation>
    </message>
</context>
<context>
    <name>DAlarmManager</name>
    <message>
        <source>Close</source>
        <comment>button</comment>
        <translation>Mbylle</translation>
    </message>
    <message>
        <source>One day before start</source>
        <translation>Një ditë para fillimit</translation>
    </message>
    <message>
        <source>Remind me tomorrow</source>
        <translation>Kujtoma nesër</translation>
    </message>
    <message>
        <source>Remind me later</source>
        <translation>Kujtoma më vonë</translation>
    </message>
    <message>
        <source>15 mins later</source>
        <translation>pas 15 minutash</translation>
    </message>
    <message>
        <source>1 hour later</source>
        <translation>pas 1 ore</translation>
    </message>
    <message>
        <source>4 hours later</source>
        <translation>pas 4 orësh</translation>
    </message>
    <message>
        <source>Tomorrow</source>
        <translation>Nesër</translation>
    </message>
    <message>
        <source>Schedule Reminder</source>
        <translation>Kujtues Planesh</translation>
    </message>
    <message>
        <source>%1 to %2</source>
        <translation>%1 deri më %2</translation>
    </message>
    <message>
        <source>Today</source>
        <translation>Sot</translation>
    </message>
</context>
<context>
    <name>JobRemindManager</name>
    <message>
        <source>One day before start</source>
        <translation type="vanished">Një ditë para fillimit</translation>
    </message>
    <message>
        <source>Close</source>
        <comment>button</comment>
        <translation type="vanished">Mbylle</translation>
    </message>
    <message>
        <source>Remind me tomorrow</source>
        <translation type="vanished">Kujtoma nesër</translation>
    </message>
    <message>
        <source>Remind me later</source>
        <translation type="vanished">Kujtoma më vonë</translation>
    </message>
    <message>
        <source>Schedule Reminder</source>
        <translation type="vanished">Kujtues Planesh</translation>
    </message>
    <message>
        <source>%1 to %2</source>
        <translation type="vanished">%1 deri më %2</translation>
    </message>
    <message>
        <source>Today</source>
        <translation type="vanished">Sot</translation>
    </message>
    <message>
        <source>Tomorrow</source>
        <translation type="vanished">Nesër</translation>
    </message>
</context>
</TS>

==> dde-calendar_5.9.14.orig.tar.xz: dde-calendar-5.9.14/translations/dde-calendar-service_sq.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="sq">
<context>
    <name>DAccountDataBase</name>
    <message>
        <source>Work</source>
        <translation>Pune</translation>
    </message>
    <message>
        <source>Life</source>
        <translation>Shtëpie</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>Tjetër</translation>
    </message>
</context>
<context>
    <name>DAlarmManager</name>
    <message>
        <source>Close</source>
        <comment>button</comment>
        <translation>Mbylle</translation>
    </message>
    <message>
        <source>One day before start</source>
        <translation>Një ditë para fillimit</translation>
    </message>
    <message>
        <source>Remind me tomorrow</source>
        <translation>Kujtoma nesër</translation>
    </message>
    <message>
        <source>Remind me later</source>
        <translation>Kujtoma më vonë</translation>
    </message>
    <message>
        <source>15 mins later</source>
        <translation>pas 15 minutash</translation>
    </message>
    <message>
        <source>1 hour later</source>
        <translation>pas 1 ore</translation>
    </message>
    <message>
        <source>4 hours later</source>
        <translation>pas 4 orësh</translation>
    </message>
    <message>
        <source>Tomorrow</source>
        <translation>Nesër</translation>
    </message>
    <message>
        <source>Schedule Reminder</source>
        <translation>Kujtues Planesh</translation>
    </message>
    <message>
        <source>%1 to %2</source>
        <translation>%1 deri më %2</translation>
    </message>
    <message>
        <source>Today</source>
        <translation>Sot</translation>
    </message>
</context>
<context>
    <name>Return</name>
    <message>
        <source>Today</source>
        <comment>Return</comment>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Return Today</name>
    <message>
        <source>Today</source>
        <comment>Return Today</comment>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>today</name>
    <message>
        <source>Today</source>
        <comment>Today</comment>
        <translation type="unfinished"/>
    </message>
</context>
</TS>
